@@ -17,7 +17,7 @@ namespace Ekos
 {
 /**
  * @class DarkLibrary
- * @short Handles aquisition & loading of dark frames for cameras. If a suitable dark frame exists,
+ * @short Handles acquisition & loading of dark frames for cameras. If a suitable dark frame exists,
  * it is loaded from disk, otherwise it gets captured and saved for later use.
  *
  * @author Jasem Mutlaq
@@ -72,5 +72,7 @@ class DarkLibrary : public QObject
         FITSView *targetImage { nullptr };
         FITSScale filter;
     } subtractParams;
+
+    bool m_TelescopeCovered { false };
 };
 }
