@@ -21,6 +21,7 @@
 #include "indi/inditelescope.h"
 #include "ekos/auxiliary/filtermanager.h"
 #include "ekos/scheduler/schedulerjob.h"
+#include "dslrinfodialog.h"
 
 #include <QTimer>
 #include <QUrl>
@@ -333,6 +334,16 @@ class Capture : public QWidget, public Ui::Capture
          */
         void setSettings(const QJsonObject &settings);
 
+        /**
+         * @brief addDSLRInfo Save DSLR Info the in the database. If the interactive dialog was open, close it.
+         * @param model Camera name
+         * @param maxW Maximum width in pixels
+         * @param maxH Maximum height in pixels
+         * @param pixelW Pixel horizontal size in microns
+         * @param pixelH Pizel vertical size in microns
+         */
+        void addDSLRInfo(const QString &model, uint32_t maxW, uint32_t maxH, double pixelW, double pixelH);
+
     public slots:
 
         /** \addtogroup CaptureDBusInterface
@@ -385,6 +396,11 @@ class Capture : public QWidget, public Ui::Capture
              */
         void captureOne();
 
+        /**
+         * @brief startFraming Like captureOne but repeating.
+         */
+        void startFraming();
+
         /**
          * @brief setExposure Set desired exposure value in seconds
          * @param value exposure values in seconds
@@ -596,7 +612,7 @@ class Capture : public QWidget, public Ui::Capture
 
         // Jobs
         void resetJobs();
-    void selectJob(QModelIndex i);
+        void selectJob(QModelIndex i);
         void editJob(QModelIndex i);
         void resetJobEdit();
         void executeJob();
@@ -672,6 +688,7 @@ class Capture : public QWidget, public Ui::Capture
         void settingsUpdated(const QJsonObject &settings);
         void newMeridianFlipStatus(Mount::MeridianFlipStatus status);
         void newMeridianFlipSetup(bool activate, double hours);
+        void dslrInfoRequested(const QString &cameraName);
 
     private:
         void setBusy(bool enable);
@@ -691,7 +708,6 @@ class Capture : public QWidget, public Ui::Capture
         void llsq(QVector<double> x, QVector<double> y, double &a, double &b);
 
         // DSLR Info
-        void addDSLRInfo(const QString &model, uint32_t maxW, uint32_t maxH, double pixelW, double pixelH);
         void cullToDSLRLimits();
         //void syncDriverToDSLRLimits();
         bool isModelinDSLRInfo(const QString &model);
@@ -711,8 +727,8 @@ class Capture : public QWidget, public Ui::Capture
         // If exposure timed out, let's handle it.
         void processCaptureTimeout();
 
-    // selection of a job
-    void selectedJobChanged(QModelIndex current, QModelIndex previous);
+        // selection of a job
+        void selectedJobChanged(QModelIndex current, QModelIndex previous);
 
         /* Capture */
 
@@ -735,6 +751,7 @@ class Capture : public QWidget, public Ui::Capture
         int nextSequenceID { 0 };
         int seqFileCount { 0 };
         bool isBusy { false };
+        bool m_isLooping { false };
 
         // Capture timeout timer
         QTimer captureTimeout;
@@ -853,6 +870,9 @@ class Capture : public QWidget, public Ui::Capture
 
         std::unique_ptr<CustomProperties> customPropertiesDialog;
 
+        void createDSLRDialog();
+        std::unique_ptr<DSLRInfo> dslrInfoDialog;
+
         // Filter Manager
         QSharedPointer<FilterManager> filterManager;
 
