@@ -122,11 +122,19 @@ Client::Client(Ekos::Manager *manager) : QDialog(manager), m_Manager(manager)
         if (job->error() == false)
         {
             QJsonObject data = QJsonDocument::fromJson(dynamic_cast<QKeychain::ReadPasswordJob*>(job)->textData().toLatin1()).object();
-            username->setText(data["username"].toString());
-            password->setText(data["password"].toString());
+            const QString usernameText = data["username"].toString();
+            const QString passwordText = data["password"].toString();
+
+            // Only set and attempt connection if the data is not empty
+            if (usernameText.isEmpty() == false && passwordText.isEmpty() == false)
+            {
+                username->setText(usernameText);
+                password->setText(passwordText);
+
+                if (autoStartCheck->isChecked())
+                    connectAuthServer();
+            }
 
-            if (autoStartCheck->isChecked())
-                connectAuthServer();
         }
         job->deleteLater();
     });
@@ -291,4 +299,29 @@ void Client::onResult(QNetworkReply *reply)
     ekosLiveOfflineR->setEnabled(false);
 }
 
+void Client::setConnected(bool enabled)
+{
+    // Return if there is no change.
+    if (enabled == m_isConnected)
+        return;
+
+    connectB->click();
+}
+
+void Client::setConfig(bool onlineService, bool rememberCredentials, bool autoConnect)
+{
+    ekosLiveOnlineR->setChecked(onlineService);
+    ekosLiveOfflineR->setChecked(!onlineService);
+
+    rememberCredentialsCheck->setChecked(rememberCredentials);
+
+    autoStartCheck->setChecked(autoConnect);
+}
+
+void Client::setUser(const QString &user, const QString &pass)
+{
+    username->setText(user);
+    password->setText(pass);
+}
+
 }
