@@ -178,7 +178,12 @@ void Message::onTextReceived(const QString &message)
     if (command == commands[GET_STATES])
         sendStates();
     else if (command == commands[GET_CAMERAS])
+    {
         sendCameras();
+        // Try to trigger any signals based on current camera list
+        if (m_Manager->captureModule())
+            m_Manager->captureModule()->checkCCD();
+    }
     else if (command == commands[GET_MOUNTS])
         sendMounts();
     else if (command == commands[GET_FILTER_WHEELS])
@@ -205,6 +210,8 @@ void Message::onTextReceived(const QString &message)
         processCapCommands(command, payload);
     else if (command.startsWith("option_"))
         processOptionsCommands(command, payload);
+    else if (command.startsWith("dslr_"))
+        processDSLRCommands(command, payload);
 }
 
 void Message::sendCameras()
@@ -437,6 +444,8 @@ void Message::processCaptureCommands(const QString &command, const QJsonObject &
         capture->start();
     else if (command == commands[CAPTURE_STOP])
         capture->stop();
+    else if (command == commands[CAPTURE_LOOP])
+        capture->startFraming();
     else if (command == commands[CAPTURE_GET_SEQUENCES])
     {
         sendCaptureSequence(capture->getSequence());
@@ -501,6 +510,12 @@ void Message::processFocusCommands(const QString &command, const QJsonObject &pa
         focus->abort();
     else if (command == commands[FOCUS_RESET])
         focus->resetFrame();
+    else if (command == commands[FOCUS_IN])
+        focus->focusIn(payload["steps"].toInt());
+    else if (command == commands[FOCUS_OUT])
+        focus->focusOut(payload["steps"].toInt());
+    else if (command == commands[FOCUS_LOOP])
+        focus->startFraming();
 }
 
 void Message::processMountCommands(const QString &command, const QJsonObject &payload)
@@ -855,6 +870,26 @@ void Message::processScopeCommands(const QString &command, const QJsonObject &pa
     sendScopes();
 }
 
+void Message::processDSLRCommands(const QString &command, const QJsonObject &payload)
+{
+    if (command == commands[DSLR_SET_INFO])
+    {
+        if (m_Manager->captureModule())
+            m_Manager->captureModule()->addDSLRInfo(
+                payload["model"].toString(),
+                payload["width"].toInt(),
+                payload["height"].toInt(),
+                payload["pixelw"].toDouble(),
+                payload["pixelw"].toDouble());
+
+    }
+}
+
+void Message::requestDSLRInfo(const QString &cameraName)
+{
+    m_WebSocket.sendTextMessage(QJsonDocument({{"type", commands[DSLR_GET_INFO]}, {"payload", cameraName}}).toJson(QJsonDocument::Compact));
+}
+
 void Message::sendResponse(const QString &command, const QJsonObject &payload)
 {
     m_WebSocket.sendTextMessage(QJsonDocument({{"type", command}, {"payload", payload}}).toJson(QJsonDocument::Compact));
